# Welcome to Lumafit's Documentation!

```{automodule} lumafit
:no-members:
```

Lumafit is a Numba-accelerated Levenberg-Marquardt fitting library optimized for performance... (Add your project description here)

This documentation provides details on installation, usage, and the API reference.

```{toctree}
:maxdepth: 2
:caption: Contents:

usage
references
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
